#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_CTZ_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_CTZ_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/simd/ctz.hpp>

#endif
